Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(503)

Unified Diff: src/virtual-frame-ia32.h

Issue 53005: Add pointers to a VirtualFrame that keep track of the indexes of register... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: '' Created 11 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/virtual-frame-arm.h ('k') | src/virtual-frame-ia32.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/virtual-frame-ia32.h
===================================================================
--- src/virtual-frame-ia32.h (revision 1589)
+++ src/virtual-frame-ia32.h (working copy)
@@ -337,6 +337,10 @@
// used in the frame.
RegisterFile frame_registers_;
+ // The index of the register frame element using each register, or
+ // kIllegalIndex if a register is not on the frame.
+ int register_locations_[kNumRegisters];
+
// The index of the first parameter. The receiver lies below the first
// parameter.
int param0_index() const { return 1; }
@@ -372,12 +376,13 @@
}
// Record an occurrence of a register in the virtual frame. This has the
- // effect of incrementing both the register's frame-internal reference
- // count and its external reference count.
- void Use(Register reg);
+ // effect of incrementing the register's external reference count and
+ // of updating the index of the register's location in the frame.
+ void Use(Register reg, int index);
// Record that a register reference has been dropped from the frame. This
- // decrements both the register's internal and external reference counts.
+ // decrements the register's external reference count and invalidates the
+ // index of the register's location in the frame.
void Unuse(Register reg);
// Spill the element at a particular index---write it to memory if
« no previous file with comments | « src/virtual-frame-arm.h ('k') | src/virtual-frame-ia32.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698